@@ -1,6 +1,6 @@
 /*
    Copyright (C) 2008-2023 J.Rios <anonbeat@gmail.com>
-   Copyright (C) 2024-2025 Tiago T Barrionuevo <thothix@protonmail.com>
+   Copyright (C) 2024-2026 Tiago T Barrionuevo <thothix@protonmail.com>
 
    This file is part of Guayadeque Music Player.
 
@@ -39,16 +39,20 @@ namespace Guayadeque {
                "song_addedtime, song_lastplay, song_filesize " \
                "FROM songs " )
 
-#define GUCOVER_THUMB_SIZE      38
-#define GUCOVER_IMAGE_SIZE      100
+#define GUCOVER_THUMB_SIZE          38
+#define GUCOVER_IMAGE_SIZE          100
 
     // PLAYLISTS
-#define guPLAYLIST_TYPE_STATIC       0
-#define guPLAYLIST_TYPE_DYNAMIC      1
+#define guPLAYLIST_TYPE_STATIC          0
+#define guPLAYLIST_TYPE_DYNAMIC         1
 
 extern unsigned long DynPLDateOption2[];
 
-#define guTRACK_TYPE_STOP_HERE      0x80000000
+#define guTRACK_TYPE_STOP_HERE          0x80000000
+
+#define guTRACKS_SORT_COLUMNS_RESTORE   -2
+#define guTRACKS_SORT_COLUMN_ASC        " ▲"
+#define guTRACKS_SORT_COLUMN_DESC       " ▼"
 
     enum guTrackType
     {
