@@ -1,6 +1,6 @@
 /*
    Copyright (C) 2008-2023 J.Rios <anonbeat@gmail.com>
-   Copyright (C) 2024-2025 Tiago T Barrionuevo <thothix@protonmail.com>
+   Copyright (C) 2024-2026 Tiago T Barrionuevo <thothix@protonmail.com>
 
    This file is part of Guayadeque Music Player.
 
@@ -85,6 +85,14 @@ bool guIsValidAudioFile( const wxString &filename )
 
         guSupportedFormats.Add( wxT( "mpc"  ) );
 
+        // TODO: Modules audio testing
+        // guSupportedFormats.Add( wxT( "mod"  ) );
+        // guSupportedFormats.Add( wxT( "s3m"  ) );
+        // guSupportedFormats.Add( wxT( "xm"  ) );
+        // guSupportedFormats.Add( wxT( "it"  ) );
+        // guSupportedFormats.Add( wxT( "mtm"  ) );
+        // guSupportedFormats.Add( wxT( "669"  ) );
+
         //guSupportedFormats.Add( wxT( "dsf"  ) );  // >= 2.0
         //guSupportedFormats.Add( wxT( "rmj"  ) );  // Real Media Jukebox
     }
@@ -141,7 +149,7 @@ guTagInfo * guGetTagInfoHandler( const wxString &filename )
 
         case 18 : return new guMpcTagInfo( filename );
 
-        case 19 : return new guMp3TagInfo( filename );     // DSD, DSF - TODO: Create a custom TagInfo
+        //case 19 : return new guMp3TagInfo( filename );     // DSD, DSF - TODO: Create a custom TagInfo
 
         default :
             break;
